@@ -8,12 +8,6 @@
 
 /**/
 
-#include <WSCmainWindow.h>
-
-extern WSCmainWindow *MainWin;
-
-/**/
-
 //----------------------------------------------------------
 //Function for the event procedure
 //----------------------------------------------------------
