@@ -25,5 +25,12 @@ void CnfNameListSelect(WSCbase* object){
 	long en = gUrl.GetEncoding( name );
 	Cnfcomb_Encoding->setProperty( WSNlabelString,
 		ConvEncodingToStr( en ) );
+
+	long skipArt = gUrl.GetSkipArt( name );
+	Cnfvifi_SkipArt->setProperty( WSNlabelString, (WSCstring)skipArt );
+	Cnfvsli_SkipArt->setProperty( WSNvalue, skipArt );
+
+	long order = gUrl.GetN( name );
+	Cnfvlab_Order->setProperty( WSNlabelString, order );
 }
 static WSCfunctionRegister  op("CnfNameListSelect",(void*)CnfNameListSelect);
