@@ -19,8 +19,10 @@ void CnfUpdatePush(WSCbase* object){
 	bool flagDown = Cnfvtog_Download->getStatus();
 	long encoding = ConvStrToEncoding(
 		Cnfcomb_Encoding->getProperty( WSNlabelString ) );
+	long skipArt = Cnfvsli_SkipArt->getProperty( WSNvalue );
 
-	gHeadLine.UpdateUrlList( oldName, name, url, flagDown, encoding );
+	gHeadLine.UpdateUrlList(
+		oldName, name, url, flagDown, encoding, skipArt );
 
 	Cnfcomb_NameList->setProperty( WSNmenuItems, gUrl.GetList() );
 	Cnfcomb_NameList->setProperty( WSNlabelString, name );
