@@ -8,13 +8,6 @@
 
 /**/
 
-#include <WSCcomboBox.h>
-
-extern WSCcomboBox *Maicomb_NameList;
-extern WSCcomboBox *Cnfcomb_NameList;
-
-/**/
-
 //----------------------------------------------------------
 //Function for the event procedure
 //----------------------------------------------------------
@@ -26,11 +19,19 @@ void CnfWinInit(WSCbase* object){
 	Cnfvlab_Name->setProperty( WSNlabelString, MesLabelName );
 	Cnfvlab_Url->setProperty( WSNlabelString, MesLabelUrl );
 	Cnfvtog_Download->setProperty( WSNlabelString, MesLabelDownload );
+	Cnfvlab_Encoding->setProperty( WSNlabelString, MesLabelEncoding );
+	Cnfvlab_SkipArt->setProperty( WSNlabelString, MesLabelSkipArt );
 
 	Cnfvbtn_DeleteBtn->setProperty( WSNlabelString, MesLabelDelete );
 	Cnfvbtn_UpdateBtn->setProperty( WSNlabelString, MesLabelUpdate );
 	Cnfvbtn_NewBtn->setProperty( WSNlabelString, MesLabelNew );
 
+	Cnfvlab_OrderTitle->setProperty( WSNlabelString, MesLabelOrder );
+	Cnfvbtn_UpBtn->setProperty( WSNlabelString, MesLabelUp );
+	Cnfvbtn_DownBtn->setProperty( WSNlabelString, MesLabelDown );
+	Cnfvbtn_TopBtn->setProperty( WSNlabelString, MesLabelTop );
+	Cnfvbtn_BottomBtn->setProperty( WSNlabelString, MesLabelBottom );
+
 	/* Set data */
 
 	Cnfcomb_Encoding->setProperty( WSNmenuItems, GetEncodingList() );
