@@ -8,27 +8,14 @@
 
 /**/
 
-#include <WSCmainWindow.h>
-#include <WSCvkslabel.h>
-#include <WSCvscrBar.h>
-#include <WSCvbtn.h>
-#include <WSCvtimer.h>
-#include <WSCcomboBox.h>
-#include <WSCmessageDialog.h>
+#define CONF_FILE_NAME	".nnhl.conf"
+#define URL_FILE_NAME	".nnhl_url"
 
-extern WSCmainWindow *MainWin;
-extern WSCvkslabel *Maivksl_HeadLine;
-extern WSCvscrBar *Maivscr_ScrollBar;
-extern WSCvbtn *Maivbtn_StopBtn;
-extern WSCvtimer *Maivtim_MainTimer;
-extern WSCvtimer *Maivtim_BeginTimer;
-extern WSCcomboBox *Maicomb_NameList;
-extern WSCvlabel *Maivlab_Art;
-extern WSCvlabel *Maivlab_Thr;
-extern WSCvlabel *Maivlab_Site;
-extern WSCvbtn *Maivbtn_PrevUrlBtn;
-extern WSCvbtn *Maivbtn_NextUrlBtn;
-extern WSCvbtn *Maivbtn_BarBtn;
+#define STR_HEADER_CONF	"# Config file Version "
+#define STR_VERSION_CONF_0_1_0	"0.1.0"
+
+#define STR_HEADER_URL	"# URL list Version "
+#define STR_VERSION_URL_0_1_0	"0.1.0"
 
 /**/
 
@@ -37,97 +24,142 @@ struct TListUrl {
 	char *url;
 	bool flagDown;
 	long encoding;
+	long skipArt;
 };
 
 TListUrl gListUrl[] = {
 	{ NMesUrlName_news2_2ch_net_news5plus_,
 		"http://news2.2ch.net/news5plus/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_sports2_2ch_net_iraq_,
 		"http://sports2.2ch.net/iraq/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news2_2ch_net_news5_,
 		"http://news2.2ch.net/news5/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_society_2ch_net_kokusai_,
 		"http://society.2ch.net/kokusai/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_tmp2_2ch_net_bakanews_,
 		"http://tmp2.2ch.net/bakanews/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_tmp2_2ch_net_asia_,
 		"http://tmp2.2ch.net/asia/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news2_2ch_net_news2_,
 		"http://news2.2ch.net/news2/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_pc_2ch_net_pcnews_,
 		"http://pc.2ch.net/pcnews/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_comic_2ch_net_comicnews_,
 		"http://comic.2ch.net/comicnews/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_music3_2ch_net_musicnews_,
 		"http://music3.2ch.net/musicnews/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news6_2ch_net_trafficinfo_,
 		"http://news6.2ch.net/trafficinfo/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news4_2ch_net_news_,
 		"http://news4.2ch.net/news/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		2,
+	},
 	{ NMesUrlName_news5_2ch_net_newsplus_,
 		"http://news5.2ch.net/newsplus/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_bbq_2ch_net_bbynews_,
 		"http://bbq.2ch.net/bbynews/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news7_2ch_net_femnewsplus_,
 		"http://news7.2ch.net/femnewsplus/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news6_2ch_net_mnewsplus_,
 		"http://news6.2ch.net/mnewsplus/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_book_2ch_net_bizplus_,
 		"http://book.2ch.net/bizplus/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news8_2ch_net_eqplus_,
 		"http://news8.2ch.net/eqplus/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesUrlName_news8_2ch_net_eq_,
 		"http://news8.2ch.net/eq/",
 		true,
-		WS_EN_SJIS, },
+		WS_EN_SJIS,
+		gSkipArtMaxN,
+	},
 	{ NMesNull,
 		NULL,
 		false,
-		WS_EN_DEFAULT, },
+		WS_EN_DEFAULT,
+		0,
+	},
 };
 
 /**/
 
 void CHeadLine::Init( void )
 {
+#if 1
 	ResetMessage( LANG_KIND_JAPANESE );
-//ResetMessage( LANG_KIND_ENGLISH );//@@@
+#else
+	ResetMessage( LANG_KIND_ENGLISH );
+#endif
+
 	Maivlab_Art->setProperty( WSNlabelString, MesLabelArt );
 	Maivlab_Thr->setProperty( WSNlabelString, MesLabelThr );
 	Maivlab_Site->setProperty( WSNlabelString, MesLabelSite );
@@ -139,15 +171,16 @@ void CHeadLine::Init( void )
 	mHeadLineMaxN = 0;
 	mFlagDown = false;
 
-	mStrHeadLine.add( new WSCstring, -1 );
-	mFlagDone.add( new bool, -1 );
-
 	mStrItem = "";
 
 	mWordIdx = 0;
 	mWordMaxIdx = 1;
+	mSkipArtCount = 0;
 
 	mStrWordSep = "\n";
+	mStrThreadSepWord = "-- Thread separator --";
+	mStrThreadSep.clear();
+	mStrThreadSep << mStrThreadSepWord << mStrWordSep;
 
 	gUrl.Init();
 	if( !Load() )
@@ -237,14 +270,37 @@ bool CHeadLine::SetDone( long n, bool done )
 
 /**/
 
-void CHeadLine::Update( long nSkip, bool flgForce )
+void CHeadLine::UpdateTimer( void )
+{
+	UpdateSub( +1, false, false );
+
+	if( mSkipArtCount >= gUrl.GetSkipArt( mHeadLineCurN ) ){
+		mSkipArtCount = 0;
+		NextThread( +1 );
+	}
+}
+
+/**/
+
+void CHeadLine::Update( long nSkip, bool flagForce )
+{
+	UpdateSub( nSkip, flagForce, true );
+}
+
+/**/
+
+void CHeadLine::UpdateSub(
+	long nSkip, bool flagForce, bool flagResetSkip )
 {
 	long scrollLen = 2;
 
 	unsigned long n = Maivscr_ScrollBar->getProperty( WSNvalue );
 	unsigned long max_n = Maivscr_ScrollBar->getProperty( WSNmaximum );
 
-	if( flgForce || ((n + scrollLen) >= max_n) ){
+	if( flagForce || ((n + scrollLen) >= max_n) ){
+		if( !flagResetSkip )
+			mSkipArtCount++;
+
 		mStrItem = GetText( nSkip );
 
 		n = 0;
@@ -262,8 +318,12 @@ void CHeadLine::Update( long nSkip, bool flgForce )
 	} else {
 		n += scrollLen;
 		Maivscr_ScrollBar->setProperty( WSNvalue, n );
+
 	}
 
+	if( flagResetSkip )
+		mSkipArtCount = 0;
+
 	Draw();
 }
 
@@ -350,6 +410,71 @@ bool CHeadLine::SetStopBtn( void )
 
 /**/
 
+void CHeadLine::PrevThread( long nSkip )
+{
+	long idx = PrevThreadSub( nSkip );
+	if( idx > 0 ){
+		Update( -idx, true );
+	} else {
+		Update( -1, true );
+
+		idx = PrevThreadSub( 1 );
+		if( idx > 0 ){
+			Update( -idx, true );
+			NextThread( 1 );
+		}
+	}
+}
+
+/**/
+
+long CHeadLine::PrevThreadSub( long nSkip )
+{
+	if( nSkip <= -1 )
+		nSkip = -nSkip;
+
+	WSCstring str = GetStr( mHeadLineCurN );
+
+	WSCstring head = str;
+	long posEnd = head.getWordCharPos( mWordIdx, mStrWordSep );
+	head.cutString( posEnd );
+
+	long maxN = head.getWords( mStrThreadSep );
+	long n = maxN - nSkip;
+	if( n < 1 )
+		n = 1;
+
+	long posBgn = head.getWordCharPos( n - 1, mStrThreadSep );
+	head.deleteChars( 0, posBgn );
+
+	return( head.getWords( mStrWordSep ) - 1 );
+}
+
+/**/
+
+void CHeadLine::NextThread( long nSkip )
+{
+	if( nSkip <= -1 )
+		nSkip = -nSkip;
+
+	WSCstring str = GetStr( mHeadLineCurN );
+
+	long posHead = str.getWordCharPos( mWordIdx, mStrWordSep );
+	WSCstring head = str;
+	head.deleteChars( 0, posHead );
+
+	long posTmp = head.getWordCharPos( nSkip, mStrThreadSep );
+	WSCstring tmp = head;
+	tmp.cutString( posTmp );
+	long idx = tmp.getWords( mStrWordSep ) - 1;
+
+	if( idx < 1 )
+		idx = 1;
+	Update( +idx, true );
+}
+
+/**/
+
 long CHeadLine::PrevUrl( void )
 {
 	IncHeadLineCurN( -1 );
@@ -399,25 +524,19 @@ void CHeadLine::ResetUrlList( void )
 		AddUrlList( Mes( gListUrl[i].mes ),
 			gListUrl[i].url,
 			gListUrl[i].flagDown,
-			gListUrl[i].encoding );
+			gListUrl[i].encoding,
+			gListUrl[i].skipArt
+		);
 	}
-#if 0
- //@@@
- AddUrlList( "SourceForge.jp", "http://lnl.sourceforge.jp/", true );
-#endif
-#if 0
- //@@@
- AddUrlList( "YuMe", "http://life4.2ch.net/yume/", true );//@@@
-#endif
 }
 
 /**/
 
 void CHeadLine::AddUrlList(
 	WSCstring name,
-	WSCstring url, bool flagDown, long encoding )
+	WSCstring url, bool flagDown, long encoding, long skipArt )
 {
-	if( !gUrl.Add( name, url, flagDown, encoding ) )
+	if( !gUrl.Add( name, url, flagDown, encoding, skipArt ) )
 		return;
 
 	Maicomb_NameList->setProperty( WSNmenuItems, gUrl.GetList() );
@@ -444,9 +563,9 @@ void CHeadLine::AddUrlList(
 
 void CHeadLine::UpdateUrlList(
 	WSCstring oldName, WSCstring name,
-	WSCstring url, bool flagDown, long encoding )
+	WSCstring url, bool flagDown, long encoding, long skipArt )
 {
-	if( !gUrl.Update( oldName, name, url, flagDown, encoding ) )
+	if( !gUrl.Update( oldName, name, url, flagDown, encoding, skipArt ) )
 		return;
 
 	long n = gUrl.GetN( name );
@@ -490,9 +609,34 @@ void CHeadLine::DeleteUrlListAll( void )
 
 /**/
 
+bool CHeadLine::Swap( long n1, long n2 )
+{
+	if( !gUrl.Swap( n1, n2 ) )
+		return false;
+
+	WSCstring *tmpStr = (WSCstring *)mStrHeadLine[n1];
+	mStrHeadLine[n1] = mStrHeadLine[n2];
+	mStrHeadLine[n2] = tmpStr;
+
+	bool *tmpFlag = (bool *)mFlagDone[n1];
+	mFlagDone[n1] = mFlagDone[n2];
+	mFlagDone[n2] = tmpFlag;
+
+	Maicomb_NameList->setProperty( WSNmenuItems, gUrl.GetList() );
+
+	IncHeadLineCurN( +-0 );
+
+	return true;
+}
+
+/**/
+
 WSCstring CHeadLine::PickUp2ch( WSCstring html )
 {
 	WSCstring text;
+	WSCstring strThreadBgn = "</a></div><b>";
+	WSCstring strThreadEnd = "</font></b>";
+	WSCstring strThread;
 	WSCstring strBgn = "<dd>";
 	WSCstring strEnd = "<dt>";
 	WSCstring strBgnSkip = "<dd><";
@@ -507,6 +651,7 @@ WSCstring CHeadLine::PickUp2ch( WSCstring html )
 		WSCstring tmp = html;
 		tmp.to_lower();
 
+		long idxThreadBgn = tmp.isExist( strThreadBgn );
 		long idxBgn = tmp.isExist( strBgn );
 		long idxEnd = tmp.isExist( strEnd );
 		long idxBgnSkip = tmp.isExist( strBgnSkip );
@@ -537,6 +682,24 @@ WSCstring CHeadLine::PickUp2ch( WSCstring html )
 				break;
 			}
 		}
+
+		if( (idxThreadBgn > -1) && (idxThreadBgn < idxBgn) ){
+			strThread = html;
+			long len = idxThreadBgn + strThreadBgn.getChars();
+			strThread.deleteChars( 0, len );
+
+			WSCstring tmp = strThread;
+			tmp.to_lower();
+			long idxThreadEnd = tmp.isExist( strThreadEnd );
+			if( idxThreadEnd > -1){
+				strThread.cutString( idxThreadEnd );
+			} else {
+				strThread.clear();
+			}
+
+			DelHtmlTag( &strThread, "<font", ">" );
+		}
+
 		if( idxEnd < idxBgn ){
 			/* There are ending token */
 			/* before beginning token. */
@@ -560,6 +723,15 @@ WSCstring CHeadLine::PickUp2ch( WSCstring html )
 		str.cutString( idxEnd );
 		str.deleteChars( 0, idxBgn );
 
+		if( strThread.getChars() > 0 ){
+			if( text.getChars() > 0 ){
+				text << mStrThreadSep;
+			}
+			text << strThread << mStrWordSep;
+
+			strThread.clear();
+		}
+
 		text << str << mStrWordSep;
 
 		/* I set HTML text to next position. */
@@ -567,6 +739,17 @@ WSCstring CHeadLine::PickUp2ch( WSCstring html )
 		html.deleteChars( 0, idxEnd );
 	}
 
+	DelHtmlHref( &text );
+
+	DelHtmlTag( &text, "<font", "</font>" );
+
+	DelHtmlStr( &text, " <br> " );
+	DelHtmlStr( &text, " <br>" );
+	DelHtmlStr( &text, "<br> " );
+	DelHtmlStr( &text, "<br>" );
+
+	ConvHtmlMetaChar( &text );
+
 	return text;
 }
 
@@ -574,30 +757,31 @@ WSCstring CHeadLine::PickUp2ch( WSCstring html )
 
 WSCstring CHeadLine::GetText( long nSkip )
 {
-	mWordIdx += nSkip;
+	/* I skip articles */
 
-	if( mWordIdx >= mWordMaxIdx ){
-		IncHeadLineCurN( +1 );
-		mWordIdx = 0;
+	WSCstring str;
+	for( long i = 0; i < 128; i++ ){
+		mWordIdx += nSkip;
+
+		if( mWordIdx >= mWordMaxIdx ){
+			IncHeadLineCurN( +1 );
+			mWordIdx = 0;
+		}
+		if( mWordIdx < 0 ){
+			IncHeadLineCurN( -1 );
+			mWordIdx = mWordMaxIdx - 1;
+		}
+
+		str = GetStr( mHeadLineCurN )
+			.getWord( mWordIdx, mStrWordSep );
+
+		if( str.getChars() <= -1 )
+			continue;
+		if( str == mStrThreadSepWord )
+			continue;
+
+		break;
 	}
-	if( mWordIdx < 0 ){
-		IncHeadLineCurN( -1 );
-		mWordIdx = mWordMaxIdx - 1;
-	}
-
-	WSCstring str = GetStr( mHeadLineCurN )
-		.getWord( mWordIdx, mStrWordSep );
-
-	str = DelHtmlHref( str );
-
-	str = DelHtmlTag( str, "<font", "</font>" );
-
-	str = DelHtmlStr( str, " <br> " );
-	str = DelHtmlStr( str, " <br>" );
-	str = DelHtmlStr( str, "<br> " );
-	str = DelHtmlStr( str, "<br>" );
-
-	str = ConvHtmlMetaChar( str );
 
 	str << "    ";
 
@@ -651,8 +835,11 @@ long CHeadLine::IncHeadLineCurN( long n )
 
 /**/
 
-WSCstring CHeadLine::DelHtmlHref( WSCstring html )
+WSCstring CHeadLine::DelHtmlHref( WSCstring *html )
 {
+	if( html == NULL )
+		return "";
+
 	WSCstring strBgn1 = "<a href";
 	WSCstring strEnd1 = "\"";
 	WSCstring strBgn2 = "\"";
@@ -669,7 +856,8 @@ WSCstring CHeadLine::DelHtmlHref( WSCstring html )
 
 		/* Begin 1 */
 
-		tmp = html;
+		tmp = *html;
+		tmp.to_lower();
 
 		long idxBgn1 = tmp.isExist( strBgn1 );
 		if( idxBgn1 <= -1 )
@@ -677,7 +865,8 @@ WSCstring CHeadLine::DelHtmlHref( WSCstring html )
 
 		/* End 1 */
 
-		tmp = html;
+		tmp = *html;
+		tmp.to_lower();
 		tmp.deleteChars( 0, idxBgn1 + lenBgn1 );
 
 		long idxEnd1 = tmp.isExist( strEnd1 );
@@ -687,7 +876,8 @@ WSCstring CHeadLine::DelHtmlHref( WSCstring html )
 
 		/* Begin 2 */
 
-		tmp = html;
+		tmp = *html;
+		tmp.to_lower();
 		tmp.deleteChars( 0, idxEnd1 + lenEnd1 );
 
 		long idxBgn2 = tmp.isExist( strBgn2 );
@@ -697,7 +887,8 @@ WSCstring CHeadLine::DelHtmlHref( WSCstring html )
 
 		/* End 2 */
 
-		tmp = html;
+		tmp = *html;
+		tmp.to_lower();
 		tmp.deleteChars( 0, idxBgn2 + lenBgn2 );
 
 		long idxEnd2 = tmp.isExist( strEnd2 );
@@ -710,29 +901,39 @@ WSCstring CHeadLine::DelHtmlHref( WSCstring html )
 		if( idxBgn2 < idxBgn1 )
 			continue;
 
-		html.deleteChars( idxBgn2, (idxEnd2 - idxBgn2) + lenEnd2 );
-		html.insertString( idxBgn2, strFoot );
-		html.deleteChars( idxBgn1, (idxEnd1 - idxBgn1) + lenEnd1 );
-		html.insertString( idxBgn1, strHead );
+		html->deleteChars( idxBgn2, (idxEnd2 - idxBgn2) + lenEnd2 );
+		html->insertString( idxBgn2, strFoot );
+		html->deleteChars( idxBgn1, (idxEnd1 - idxBgn1) + lenEnd1 );
+		html->insertString( idxBgn1, strHead );
 	}
 
-	return html;
+	return *html;
 }
 
 /**/
 
 WSCstring CHeadLine::DelHtmlTag(
-	WSCstring html,
+	WSCstring *html,
 	WSCstring strBgn, WSCstring strEnd )
 {
+	if( html == NULL )
+		return "";
+
+	strBgn.to_lower();
+	strEnd.to_lower();
+
 	long lenEnd = strEnd.getChars();
 
 	while( 1 ){
-		long idxBgn = html.isExist( strBgn );
+		WSCstring tmp = *html;
+		tmp.to_lower();
+
+		long idxBgn = tmp.isExist( strBgn );
 		if( idxBgn <= -1 )
 			break;
 
-		WSCstring tmp = html;
+		tmp = *html;
+		tmp.to_lower();
 		tmp.deleteChars( 0, idxBgn );
 
 		long idxEnd = tmp.isExist( strEnd );
@@ -744,25 +945,42 @@ WSCstring CHeadLine::DelHtmlTag(
 			break;
 
 		idxEnd += lenEnd;
-		html.deleteChars( idxBgn, idxEnd - idxBgn );
+		html->deleteChars( idxBgn, idxEnd - idxBgn );
 	}
 
-	return html;
+	return *html;
 }
 
 /**/
 
-WSCstring CHeadLine::DelHtmlStr( WSCstring html, WSCstring str )
+WSCstring CHeadLine::DelHtmlStr( WSCstring *html, WSCstring str )
 {
-	html.delString( str, 0 );
+	if( html == NULL )
+		return "";
 
-	return html;
+	str.to_lower();
+	WSCstring tmp = *html;
+	tmp.to_lower();
+
+	while( 1 ){
+		long idx = tmp.isExist( str );
+		if( idx <= -1 )
+			break;
+
+		html->deleteChars( idx, str.getChars() );
+		tmp.deleteChars( idx, str.getChars() );
+	}
+
+	return *html;
 }
 
 /**/
 
-WSCstring CHeadLine::ConvHtmlMetaChar( WSCstring html )
+WSCstring CHeadLine::ConvHtmlMetaChar( WSCstring *html )
 {
+	if( html == NULL )
+		return "";
+
 	WSCstring listMeta[][2] = {
 		{
 			"&gt;",
@@ -783,10 +1001,10 @@ WSCstring CHeadLine::ConvHtmlMetaChar( WSCstring html )
 			break;
 		}
 
-		html.replaceString( listMeta[i][0], listMeta[i][1], 0 );
+		html->replaceString( listMeta[i][0], listMeta[i][1], 0 );
 	}
 
-	return html;
+	return *html;
 }
 
 /**/
@@ -816,21 +1034,76 @@ void CHeadLine::SetDownText( long n, WSCstring str )
 /**/
 
 bool CHeadLine::Save( void )
+{
+	bool ret = true;
+
+	if( !SaveConfig() )
+		ret = false;
+	if( !SaveUrl() )
+		ret = false;
+
+	return ret;
+}
+
+/**/
+
+bool CHeadLine::SaveConfig( void )
 {
 	WSCstring str;
+	str << "\"\",\""
+		<< "\",\""
+		<< STR_HEADER_CONF STR_VERSION_CONF_0_1_0 << "\",\""
+		<< "\",\""
+		<< "\",\""
+		<< "\",\""
+		<< "\"\n";
+
+	WSCstring fileName = ConvHomeFileName( CONF_FILE_NAME );
+
+	long res = WSGFreplaceTextFile( fileName, str, false );
+	if( res != WS_NO_ERR ){
+		WSCstring mes;
+		mes << MesSaveError << "\n(" << fileName << ")";
+
+		PopupError( mes );
+		return false;
+	}
+
+	return true;
+}
+
+/**/
+
+bool CHeadLine::SaveUrl( void )
+{
+	WSCstring str;
+	str << "\"\",\""
+		<< "\",\""
+		<< STR_HEADER_URL STR_VERSION_URL_0_1_0 << "\",\""
+		<< "\",\""
+		<< "\",\""
+		<< "\",\""
+		<< "\"\n";
+
 	for( long i = 0; i < gUrl.GetMaxN(); i++ ){
 		long en = gUrl.GetEncoding( i );
 		str << "\"\",\""
+			<< gUrl.GetFlagDownload( i ) << "\",\""
 			<< gUrl.GetName( i ) << "\",\""
 			<< gUrl.GetUrl( i ) << "\",\""
-			<< gUrl.GetFlagDownload( i ) << "\",\""
 			<< ConvEncodingToStr( en ) << "\",\""
+			<< gUrl.GetSkipArt( i ) << "\",\""
 			<< "\"\n";
 	}
 
-	long res = WSGFreplaceTextFile( CONFIG_FILE_NAME, str, false );
+	WSCstring fileName = ConvHomeFileName( URL_FILE_NAME );
+
+	long res = WSGFreplaceTextFile( fileName, str, false );
 	if( res != WS_NO_ERR ){
-		PopupError( MesUrlListSaveError );
+		WSCstring mes;
+		mes << MesSaveError << "\n(" << fileName << ")";
+
+		PopupError( mes );
 		return false;
 	}
 
@@ -841,25 +1114,72 @@ bool CHeadLine::Save( void )
 
 bool CHeadLine::Load( void )
 {
-	if( !WSGFcheckExistFile( CONFIG_FILE_NAME ) )
+	bool ret = true;
+
+	if( !LoadConfig() )
+		ret = false;
+	if( !LoadUrl() )
+		ret = false;
+
+	return ret;
+}
+
+/**/
+
+bool CHeadLine::LoadConfig( void )
+{
+	return true;
+}
+
+/**/
+
+bool CHeadLine::LoadUrl( void )
+{
+	WSCstring fileName = ConvHomeFileName( URL_FILE_NAME );
+
+	if( !WSGFcheckExistFile( fileName ) )
 		return false;
 
-	WSCstring *str = WSGFreadTextFile( CONFIG_FILE_NAME );
-	long strMaxLine = str->getWords( "\n" ) - 1;
+	WSCstring *str = WSGFreadTextFile( fileName );
+	WSCstring header = str->getWord( 0, "\n" );
+	WSCstring ver = header.getWord( 2, "\",\"" );
 
 	DeleteUrlListAll();
 
-	for( long i = strMaxLine - 1; i >= 0; i-- ){
+	if( CompareString( ver, STR_HEADER_URL STR_VERSION_URL_0_1_0 ) ){
+		LoadUrl_0_1( str );
+	} else {
+		WSCstring mes;
+		mes << MesLoadVerError << "\n(" << fileName << ")";
+
+		PopupError( mes );
+		return false;
+	}
+
+	return true;
+}
+
+/**/
+
+bool CHeadLine::LoadUrl_0_1( WSCstring *str )
+{
+	long strMaxLine = str->getWords( "\n" ) - 1;
+
+	for( long i = strMaxLine - 1; i >= 1; i-- ){
 		/* I split lines. */
 
 		WSCstring line = str->getWord( i, "\n" );
 
 		/* I split CSV data. */
 
-		WSCstring name = line.getWord( 1, "\",\"" );
-		WSCstring url = line.getWord( 2, "\",\"" );
-		WSCstring tmpFlag = line.getWord( 3, "\",\"" );
+		WSCstring tmpFlag = line.getWord( 1, "\",\"" );
+		WSCstring name = line.getWord( 2, "\",\"" );
+		WSCstring url = line.getWord( 3, "\",\"" );
 		WSCstring tmpEn = line.getWord( 4, "\",\"" );
+		WSCstring tmpSkipArt = line.getWord( 5, "\",\"" );
+
+		if( name.getChars() < 1 )
+			continue;
 
 		/* Flag download */
 
@@ -873,9 +1193,13 @@ bool CHeadLine::Load( void )
 
 		long en = ConvStrToEncoding( tmpEn );
 
+		/* Skip articles No. */
+
+		long skipArt = strtol( tmpSkipArt, NULL, 10 );
+
 		/* I add URL list. */
 
-		AddUrlList( name, url, flagDown, en );
+		AddUrlList( name, url, flagDown, en, skipArt );
 	}
 
 	delete str;
@@ -987,17 +1311,17 @@ void *BGDownLoad( void *arg )
 
 		/* Finish. */
 
-		if( flagFirst ){
-			if( curN == hl.mHeadLineCurN ){
-				hl.IncHeadLineCurN( +-0 );
-				hl.Update( 0, true );
-			}
-			hl.Play();
-		}
-
 		hl.SetDone( curN, true );
 		hl.mFlagDown = true;
 
+		if( curN == hl.mHeadLineCurN ){
+			hl.IncHeadLineCurN( +-0 );
+			hl.Update( 0, true );
+		}
+		if( flagFirst ){
+			hl.Play();
+		}
+
 		SleepSec( 10 );
 	}
 
