@@ -1,6 +1,13 @@
 #include <WScom.h>
 #include <WSCfunctionList.h>
 #include <WSCbase.h>
+
+/**/
+
+#include "Common.h"
+
+/**/
+
 //----------------------------------------------------------
 //Function for the event procedure
 //----------------------------------------------------------
