@@ -13,6 +13,6 @@
 //----------------------------------------------------------
 void MainTimerUpdate(WSCbase* object){
   //do something...
-	gHeadLine.Update( +1, false );
+	gHeadLine.UpdateTimer();
 }
 static WSCfunctionRegister  op("MainTimerUpdate",(void*)MainTimerUpdate);
