@@ -18,6 +18,7 @@
 #include <WSCdialog.h>
 #include <WSCvifield.h>
 #include <WSCvtoggle.h>
+#include <WSCvslider.h>
 
 //--- OBJECT instance variable ---//
 WSCmainWindow* MainWin;
@@ -38,7 +39,7 @@ WSCvbtn* Maivbtn_PrevThrBtn;
 WSCvlabel* Maivlab_Site;
 WSCvbtn* Maivbtn_BarBtn;
 WSCvtimer* Maivtim_UpdateTimer;
-WSCmenuArea* Maimenu_000;
+WSCmenuArea* Maimenu_MainMenu;
 WSCpulldownMenu* Maipull_MainMenuFile;
 WSCpulldownMenu* Maipull_MainMenuOpt;
 WSCdialog* Cnfdial_ConfigUrl;
@@ -53,6 +54,16 @@ WSCvbtn* Cnfvbtn_DeleteBtn;
 WSCcomboBox* Cnfcomb_NameList;
 WSCcomboBox* Cnfcomb_Encoding;
 WSCvlabel* Cnfvlab_Encoding;
+WSCvlabel* Cnfvlab_OrderTitle;
+WSCvlabel* Cnfvlab_Order;
+WSCvbtn* Cnfvbtn_UpBtn;
+WSCvbtn* Cnfvbtn_DownBtn;
+WSCvbtn* Cnfvbtn_TopBtn;
+WSCvbtn* Cnfvbtn_BottomBtn;
+WSCvlabel* Cnfvlab_SkipArt;
+WSCvslider* Cnfvsli_SkipArt;
+WSCvifield* Cnfvifi_SkipArt;
+WSCvtimer* Maivtim_ReloadTimer;
 
 //--- OBJECT src ---//
 
@@ -127,7 +138,7 @@ WSCbase* _create_win_MainWin(){
 
   Maivscr_ScrollBar = new  WSCvscrBar(MainWin,"Maivscr_ScrollBar");
       Maivscr_ScrollBar->initialize();
-  Maivscr_ScrollBar->setPropertyV(WSNvalue,(unsigned long)230);
+  Maivscr_ScrollBar->setPropertyV(WSNvalue,(unsigned long)260);
   Maivscr_ScrollBar->setPropertyV(WSNname,"Maivscr_ScrollBar");
   Maivscr_ScrollBar->setPropertyV(WSNvis,(WSCbool)1);
   Maivscr_ScrollBar->setPropertyV(WSNx,(short)20);
@@ -391,17 +402,17 @@ WSCbase* _create_win_MainWin(){
     op_Maivtim_UpdateTimer_5->setFunction(UpdateTimerUpdate,"UpdateTimerUpdate");
     Maivtim_UpdateTimer->addProcedure(op_Maivtim_UpdateTimer_5);
 
-  Maimenu_000 = new  WSCmenuArea(MainWin,"Maimenu_000");
-      Maimenu_000->initialize();
-  Maimenu_000->setPropertyV(WSNname,"Maimenu_000");
-  Maimenu_000->setPropertyV(WSNx,(short)0);
-  Maimenu_000->setPropertyV(WSNy,(short)0);
-  Maimenu_000->setPropertyV(WSNwidth,(unsigned short)669);
-  Maimenu_000->setPropertyV(WSNvis,(WSCbool)1);
-  Maimenu_000->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
-  Maimenu_000->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
+  Maimenu_MainMenu = new  WSCmenuArea(MainWin,"Maimenu_MainMenu");
+      Maimenu_MainMenu->initialize();
+  Maimenu_MainMenu->setPropertyV(WSNname,"Maimenu_MainMenu");
+  Maimenu_MainMenu->setPropertyV(WSNx,(short)0);
+  Maimenu_MainMenu->setPropertyV(WSNy,(short)0);
+  Maimenu_MainMenu->setPropertyV(WSNwidth,(unsigned short)669);
+  Maimenu_MainMenu->setPropertyV(WSNvis,(WSCbool)1);
+  Maimenu_MainMenu->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+  Maimenu_MainMenu->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
 
-  Maipull_MainMenuFile = new  WSCpulldownMenu(Maimenu_000,"Maipull_MainMenuFile");
+  Maipull_MainMenuFile = new  WSCpulldownMenu(Maimenu_MainMenu,"Maipull_MainMenuFile");
       Maipull_MainMenuFile->initialize();
   Maipull_MainMenuFile->setPropertyV(WSNmenuItems,"Exit(X):MainMenuExit:X:1");
   Maipull_MainMenuFile->setPropertyV(WSNshortcut,"F");
@@ -415,7 +426,7 @@ WSCbase* _create_win_MainWin(){
     op_Maipull_MainMenuFile_5->setFunction(MainMenuExit,"MainMenuExit");
     Maipull_MainMenuFile->addProcedure(op_Maipull_MainMenuFile_5);
 
-  Maipull_MainMenuOpt = new  WSCpulldownMenu(Maimenu_000,"Maipull_MainMenuOpt");
+  Maipull_MainMenuOpt = new  WSCpulldownMenu(Maimenu_MainMenu,"Maipull_MainMenuOpt");
       Maipull_MainMenuOpt->initialize();
   Maipull_MainMenuOpt->setPropertyV(WSNmenuItems,"Config URL(U):MainMenuCnfUrl:U:1");
   Maipull_MainMenuOpt->setPropertyV(WSNshortcut,"O");
@@ -437,8 +448,8 @@ WSCbase* _create_win_MainWin(){
   Cnfdial_ConfigUrl->setPropertyV(WSNtitleString,"Config URL");
   Cnfdial_ConfigUrl->setPropertyV(WSNx,(short)100);
   Cnfdial_ConfigUrl->setPropertyV(WSNy,(short)100);
-  Cnfdial_ConfigUrl->setPropertyV(WSNwidth,(unsigned short)500);
-  Cnfdial_ConfigUrl->setPropertyV(WSNheight,(unsigned short)320);
+  Cnfdial_ConfigUrl->setPropertyV(WSNwidth,(unsigned short)640);
+  Cnfdial_ConfigUrl->setPropertyV(WSNheight,(unsigned short)400);
     WSCprocedure* op_Cnfdial_ConfigUrl_5 = new WSCprocedure("CnfWinInit",0);
     extern void CnfWinInit(WSCbase*);
     op_Cnfdial_ConfigUrl_5->setFunction(CnfWinInit,"CnfWinInit");
@@ -450,11 +461,12 @@ WSCbase* _create_win_MainWin(){
 
   Cnfvbtn_NewBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_NewBtn");
       Cnfvbtn_NewBtn->initialize();
+  Cnfvbtn_NewBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
   Cnfvbtn_NewBtn->setPropertyV(WSNlabelString,"New");
   Cnfvbtn_NewBtn->setPropertyV(WSNname,"Cnfvbtn_NewBtn");
   Cnfvbtn_NewBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Cnfvbtn_NewBtn->setPropertyV(WSNx,(short)380);
-  Cnfvbtn_NewBtn->setPropertyV(WSNy,(short)240);
+  Cnfvbtn_NewBtn->setPropertyV(WSNx,(short)520);
+  Cnfvbtn_NewBtn->setPropertyV(WSNy,(short)320);
   Cnfvbtn_NewBtn->setPropertyV(WSNanchorBottom,(unsigned short)50);
   Cnfvbtn_NewBtn->setPropertyV(WSNanchorRight,(unsigned short)20);
   Cnfvbtn_NewBtn->setPropertyV(WSNanchorBottomFlag,(WSCbool)1);
@@ -466,11 +478,12 @@ WSCbase* _create_win_MainWin(){
 
   Cnfvbtn_UpdateBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_UpdateBtn");
       Cnfvbtn_UpdateBtn->initialize();
+  Cnfvbtn_UpdateBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
   Cnfvbtn_UpdateBtn->setPropertyV(WSNlabelString,"Update");
   Cnfvbtn_UpdateBtn->setPropertyV(WSNname,"Cnfvbtn_UpdateBtn");
   Cnfvbtn_UpdateBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Cnfvbtn_UpdateBtn->setPropertyV(WSNx,(short)260);
-  Cnfvbtn_UpdateBtn->setPropertyV(WSNy,(short)240);
+  Cnfvbtn_UpdateBtn->setPropertyV(WSNx,(short)400);
+  Cnfvbtn_UpdateBtn->setPropertyV(WSNy,(short)320);
   Cnfvbtn_UpdateBtn->setPropertyV(WSNanchorBottom,(unsigned short)50);
   Cnfvbtn_UpdateBtn->setPropertyV(WSNanchorRight,(unsigned short)140);
   Cnfvbtn_UpdateBtn->setPropertyV(WSNanchorBottomFlag,(WSCbool)1);
@@ -485,11 +498,11 @@ WSCbase* _create_win_MainWin(){
   Cnfvifi_Name->setPropertyV(WSNusePixmap,(WSCbool)1);
   Cnfvifi_Name->setPropertyV(WSNname,"Cnfvifi_Name");
   Cnfvifi_Name->setPropertyV(WSNvis,(WSCbool)1);
-  Cnfvifi_Name->setPropertyV(WSNx,(short)100);
+  Cnfvifi_Name->setPropertyV(WSNx,(short)120);
   Cnfvifi_Name->setPropertyV(WSNy,(short)60);
-  Cnfvifi_Name->setPropertyV(WSNwidth,(unsigned short)380);
+  Cnfvifi_Name->setPropertyV(WSNwidth,(unsigned short)500);
   Cnfvifi_Name->setPropertyV(WSNanchorTop,(unsigned short)60);
-  Cnfvifi_Name->setPropertyV(WSNanchorLeft,(unsigned short)100);
+  Cnfvifi_Name->setPropertyV(WSNanchorLeft,(unsigned short)120);
   Cnfvifi_Name->setPropertyV(WSNanchorRight,(unsigned short)20);
   Cnfvifi_Name->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
   Cnfvifi_Name->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
@@ -500,11 +513,11 @@ WSCbase* _create_win_MainWin(){
   Cnfvifi_Url->setPropertyV(WSNusePixmap,(WSCbool)1);
   Cnfvifi_Url->setPropertyV(WSNname,"Cnfvifi_Url");
   Cnfvifi_Url->setPropertyV(WSNvis,(WSCbool)1);
-  Cnfvifi_Url->setPropertyV(WSNx,(short)100);
+  Cnfvifi_Url->setPropertyV(WSNx,(short)120);
   Cnfvifi_Url->setPropertyV(WSNy,(short)100);
-  Cnfvifi_Url->setPropertyV(WSNwidth,(unsigned short)380);
+  Cnfvifi_Url->setPropertyV(WSNwidth,(unsigned short)500);
   Cnfvifi_Url->setPropertyV(WSNanchorTop,(unsigned short)100);
-  Cnfvifi_Url->setPropertyV(WSNanchorLeft,(unsigned short)100);
+  Cnfvifi_Url->setPropertyV(WSNanchorLeft,(unsigned short)120);
   Cnfvifi_Url->setPropertyV(WSNanchorRight,(unsigned short)20);
   Cnfvifi_Url->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
   Cnfvifi_Url->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
@@ -518,7 +531,6 @@ WSCbase* _create_win_MainWin(){
   Cnfvlab_Name->setPropertyV(WSNvis,(WSCbool)1);
   Cnfvlab_Name->setPropertyV(WSNx,(short)20);
   Cnfvlab_Name->setPropertyV(WSNy,(short)60);
-  Cnfvlab_Name->setPropertyV(WSNwidth,(unsigned short)80);
   Cnfvlab_Name->setPropertyV(WSNanchorTop,(unsigned short)60);
   Cnfvlab_Name->setPropertyV(WSNanchorLeft,(unsigned short)20);
   Cnfvlab_Name->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
@@ -532,7 +544,6 @@ WSCbase* _create_win_MainWin(){
   Cnfvlab_Url->setPropertyV(WSNvis,(WSCbool)1);
   Cnfvlab_Url->setPropertyV(WSNx,(short)20);
   Cnfvlab_Url->setPropertyV(WSNy,(short)100);
-  Cnfvlab_Url->setPropertyV(WSNwidth,(unsigned short)80);
   Cnfvlab_Url->setPropertyV(WSNanchorTop,(unsigned short)100);
   Cnfvlab_Url->setPropertyV(WSNanchorLeft,(unsigned short)20);
   Cnfvlab_Url->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
@@ -545,20 +556,21 @@ WSCbase* _create_win_MainWin(){
   Cnfvtog_Download->setPropertyV(WSNname,"Cnfvtog_Download");
   Cnfvtog_Download->setPropertyV(WSNvis,(WSCbool)1);
   Cnfvtog_Download->setPropertyV(WSNx,(short)20);
-  Cnfvtog_Download->setPropertyV(WSNy,(short)180);
+  Cnfvtog_Download->setPropertyV(WSNy,(short)260);
   Cnfvtog_Download->setPropertyV(WSNwidth,(unsigned short)200);
-  Cnfvtog_Download->setPropertyV(WSNanchorTop,(unsigned short)180);
+  Cnfvtog_Download->setPropertyV(WSNanchorTop,(unsigned short)260);
   Cnfvtog_Download->setPropertyV(WSNanchorLeft,(unsigned short)20);
   Cnfvtog_Download->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
   Cnfvtog_Download->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
 
   Cnfvbtn_DeleteBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_DeleteBtn");
       Cnfvbtn_DeleteBtn->initialize();
+  Cnfvbtn_DeleteBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
   Cnfvbtn_DeleteBtn->setPropertyV(WSNlabelString,"Delete");
   Cnfvbtn_DeleteBtn->setPropertyV(WSNname,"Cnfvbtn_DeleteBtn");
   Cnfvbtn_DeleteBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Cnfvbtn_DeleteBtn->setPropertyV(WSNx,(short)140);
-  Cnfvbtn_DeleteBtn->setPropertyV(WSNy,(short)240);
+  Cnfvbtn_DeleteBtn->setPropertyV(WSNx,(short)280);
+  Cnfvbtn_DeleteBtn->setPropertyV(WSNy,(short)320);
   Cnfvbtn_DeleteBtn->setPropertyV(WSNanchorBottom,(unsigned short)50);
   Cnfvbtn_DeleteBtn->setPropertyV(WSNanchorRight,(unsigned short)260);
   Cnfvbtn_DeleteBtn->setPropertyV(WSNanchorBottomFlag,(WSCbool)1);
@@ -573,13 +585,14 @@ WSCbase* _create_win_MainWin(){
   Cnfcomb_NameList->setPropertyV(WSNmenuItems,"");
   Cnfcomb_NameList->setPropertyV(WSNbackBlinkColor,"DEF13");
   Cnfcomb_NameList->setPropertyV(WSNworkBackColor,"DEF11");
+  Cnfcomb_NameList->setPropertyV(WSNusePixmap,(unsigned char)1);
   Cnfcomb_NameList->setPropertyV(WSNalignmentH,(unsigned char)0);
   Cnfcomb_NameList->setPropertyV(WSNmaxLength,(unsigned short)512);
   Cnfcomb_NameList->setPropertyV(WSNfont,(unsigned char)1);
   Cnfcomb_NameList->setPropertyV(WSNname,"Cnfcomb_NameList");
   Cnfcomb_NameList->setPropertyV(WSNx,(short)20);
   Cnfcomb_NameList->setPropertyV(WSNy,(short)20);
-  Cnfcomb_NameList->setPropertyV(WSNwidth,(unsigned short)460);
+  Cnfcomb_NameList->setPropertyV(WSNwidth,(unsigned short)600);
   Cnfcomb_NameList->setPropertyV(WSNvis,(WSCbool)1);
   Cnfcomb_NameList->setPropertyV(WSNanchorTop,(unsigned short)20);
   Cnfcomb_NameList->setPropertyV(WSNanchorLeft,(unsigned short)20);
@@ -597,12 +610,14 @@ WSCbase* _create_win_MainWin(){
   Cnfcomb_Encoding->setPropertyV(WSNmenuItems,"");
   Cnfcomb_Encoding->setPropertyV(WSNbackBlinkColor,"DEF13");
   Cnfcomb_Encoding->setPropertyV(WSNworkBackColor,"DEF11");
+  Cnfcomb_Encoding->setPropertyV(WSNusePixmap,(unsigned char)1);
   Cnfcomb_Encoding->setPropertyV(WSNname,"Cnfcomb_Encoding");
+  Cnfcomb_Encoding->setPropertyV(WSNx,(short)120);
   Cnfcomb_Encoding->setPropertyV(WSNy,(short)140);
-  Cnfcomb_Encoding->setPropertyV(WSNwidth,(unsigned short)380);
+  Cnfcomb_Encoding->setPropertyV(WSNwidth,(unsigned short)500);
   Cnfcomb_Encoding->setPropertyV(WSNvis,(WSCbool)1);
   Cnfcomb_Encoding->setPropertyV(WSNanchorTop,(unsigned short)140);
-  Cnfcomb_Encoding->setPropertyV(WSNanchorLeft,(unsigned short)100);
+  Cnfcomb_Encoding->setPropertyV(WSNanchorLeft,(unsigned short)120);
   Cnfcomb_Encoding->setPropertyV(WSNanchorRight,(unsigned short)20);
   Cnfcomb_Encoding->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
   Cnfcomb_Encoding->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
@@ -616,12 +631,169 @@ WSCbase* _create_win_MainWin(){
   Cnfvlab_Encoding->setPropertyV(WSNvis,(WSCbool)1);
   Cnfvlab_Encoding->setPropertyV(WSNx,(short)20);
   Cnfvlab_Encoding->setPropertyV(WSNy,(short)140);
-  Cnfvlab_Encoding->setPropertyV(WSNwidth,(unsigned short)80);
   Cnfvlab_Encoding->setPropertyV(WSNanchorTop,(unsigned short)140);
   Cnfvlab_Encoding->setPropertyV(WSNanchorLeft,(unsigned short)20);
   Cnfvlab_Encoding->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
   Cnfvlab_Encoding->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
 
+  Cnfvlab_OrderTitle = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_OrderTitle");
+      Cnfvlab_OrderTitle->initialize();
+  Cnfvlab_OrderTitle->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvlab_OrderTitle->setPropertyV(WSNlabelString,"Order");
+  Cnfvlab_OrderTitle->setPropertyV(WSNname,"Cnfvlab_OrderTitle");
+  Cnfvlab_OrderTitle->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvlab_OrderTitle->setPropertyV(WSNx,(short)20);
+  Cnfvlab_OrderTitle->setPropertyV(WSNy,(short)220);
+  Cnfvlab_OrderTitle->setPropertyV(WSNanchorTop,(unsigned short)220);
+  Cnfvlab_OrderTitle->setPropertyV(WSNanchorLeft,(unsigned short)20);
+  Cnfvlab_OrderTitle->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvlab_OrderTitle->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+
+  Cnfvlab_Order = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_Order");
+      Cnfvlab_Order->initialize();
+  Cnfvlab_Order->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvlab_Order->setPropertyV(WSNlabelString,"0");
+  Cnfvlab_Order->setPropertyV(WSNname,"Cnfvlab_Order");
+  Cnfvlab_Order->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvlab_Order->setPropertyV(WSNx,(short)120);
+  Cnfvlab_Order->setPropertyV(WSNy,(short)220);
+  Cnfvlab_Order->setPropertyV(WSNanchorTop,(unsigned short)220);
+  Cnfvlab_Order->setPropertyV(WSNanchorLeft,(unsigned short)120);
+  Cnfvlab_Order->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvlab_Order->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+
+  Cnfvbtn_UpBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_UpBtn");
+      Cnfvbtn_UpBtn->initialize();
+  Cnfvbtn_UpBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvbtn_UpBtn->setPropertyV(WSNlabelString,"Up");
+  Cnfvbtn_UpBtn->setPropertyV(WSNname,"Cnfvbtn_UpBtn");
+  Cnfvbtn_UpBtn->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvbtn_UpBtn->setPropertyV(WSNx,(short)220);
+  Cnfvbtn_UpBtn->setPropertyV(WSNy,(short)220);
+  Cnfvbtn_UpBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
+  Cnfvbtn_UpBtn->setPropertyV(WSNanchorLeft,(unsigned short)220);
+  Cnfvbtn_UpBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvbtn_UpBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Cnfvbtn_UpBtn_5 = new WSCprocedure("CnfUpPush",2);
+    extern void CnfUpPush(WSCbase*);
+    op_Cnfvbtn_UpBtn_5->setFunction(CnfUpPush,"CnfUpPush");
+    Cnfvbtn_UpBtn->addProcedure(op_Cnfvbtn_UpBtn_5);
+
+  Cnfvbtn_DownBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_DownBtn");
+      Cnfvbtn_DownBtn->initialize();
+  Cnfvbtn_DownBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvbtn_DownBtn->setPropertyV(WSNlabelString,"Down");
+  Cnfvbtn_DownBtn->setPropertyV(WSNname,"Cnfvbtn_DownBtn");
+  Cnfvbtn_DownBtn->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvbtn_DownBtn->setPropertyV(WSNx,(short)320);
+  Cnfvbtn_DownBtn->setPropertyV(WSNy,(short)220);
+  Cnfvbtn_DownBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
+  Cnfvbtn_DownBtn->setPropertyV(WSNanchorLeft,(unsigned short)320);
+  Cnfvbtn_DownBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvbtn_DownBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Cnfvbtn_DownBtn_5 = new WSCprocedure("CnfDownPush",2);
+    extern void CnfDownPush(WSCbase*);
+    op_Cnfvbtn_DownBtn_5->setFunction(CnfDownPush,"CnfDownPush");
+    Cnfvbtn_DownBtn->addProcedure(op_Cnfvbtn_DownBtn_5);
+
+  Cnfvbtn_TopBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_TopBtn");
+      Cnfvbtn_TopBtn->initialize();
+  Cnfvbtn_TopBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvbtn_TopBtn->setPropertyV(WSNlabelString,"Top");
+  Cnfvbtn_TopBtn->setPropertyV(WSNname,"Cnfvbtn_TopBtn");
+  Cnfvbtn_TopBtn->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvbtn_TopBtn->setPropertyV(WSNx,(short)420);
+  Cnfvbtn_TopBtn->setPropertyV(WSNy,(short)220);
+  Cnfvbtn_TopBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
+  Cnfvbtn_TopBtn->setPropertyV(WSNanchorLeft,(unsigned short)420);
+  Cnfvbtn_TopBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvbtn_TopBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Cnfvbtn_TopBtn_5 = new WSCprocedure("CnfTopPush",2);
+    extern void CnfTopPush(WSCbase*);
+    op_Cnfvbtn_TopBtn_5->setFunction(CnfTopPush,"CnfTopPush");
+    Cnfvbtn_TopBtn->addProcedure(op_Cnfvbtn_TopBtn_5);
+
+  Cnfvbtn_BottomBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_BottomBtn");
+      Cnfvbtn_BottomBtn->initialize();
+  Cnfvbtn_BottomBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvbtn_BottomBtn->setPropertyV(WSNlabelString,"Bottom");
+  Cnfvbtn_BottomBtn->setPropertyV(WSNname,"Cnfvbtn_BottomBtn");
+  Cnfvbtn_BottomBtn->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvbtn_BottomBtn->setPropertyV(WSNx,(short)520);
+  Cnfvbtn_BottomBtn->setPropertyV(WSNy,(short)220);
+  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
+  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorLeft,(unsigned short)520);
+  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Cnfvbtn_BottomBtn_5 = new WSCprocedure("CnfBottomPush",2);
+    extern void CnfBottomPush(WSCbase*);
+    op_Cnfvbtn_BottomBtn_5->setFunction(CnfBottomPush,"CnfBottomPush");
+    Cnfvbtn_BottomBtn->addProcedure(op_Cnfvbtn_BottomBtn_5);
+
+  Cnfvlab_SkipArt = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_SkipArt");
+      Cnfvlab_SkipArt->initialize();
+  Cnfvlab_SkipArt->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvlab_SkipArt->setPropertyV(WSNlabelString,"Skip Article No.");
+  Cnfvlab_SkipArt->setPropertyV(WSNname,"Cnfvlab_SkipArt");
+  Cnfvlab_SkipArt->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvlab_SkipArt->setPropertyV(WSNx,(short)20);
+  Cnfvlab_SkipArt->setPropertyV(WSNy,(short)180);
+  Cnfvlab_SkipArt->setPropertyV(WSNwidth,(unsigned short)200);
+  Cnfvlab_SkipArt->setPropertyV(WSNanchorTop,(unsigned short)180);
+  Cnfvlab_SkipArt->setPropertyV(WSNanchorLeft,(unsigned short)20);
+  Cnfvlab_SkipArt->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvlab_SkipArt->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+
+  Cnfvsli_SkipArt = new  WSCvslider(Cnfdial_ConfigUrl,"Cnfvsli_SkipArt");
+      Cnfvsli_SkipArt->initialize();
+  Cnfvsli_SkipArt->setPropertyV(WSNsliderSize,(unsigned short)10);
+  Cnfvsli_SkipArt->setPropertyV(WSNminimum,(short)1);
+  Cnfvsli_SkipArt->setPropertyV(WSNdragInterval,(unsigned short)1);
+  Cnfvsli_SkipArt->setPropertyV(WSNvalue,(short)1000);
+  Cnfvsli_SkipArt->setPropertyV(WSNname,"Cnfvsli_SkipArt");
+  Cnfvsli_SkipArt->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvsli_SkipArt->setPropertyV(WSNx,(short)320);
+  Cnfvsli_SkipArt->setPropertyV(WSNy,(short)180);
+  Cnfvsli_SkipArt->setPropertyV(WSNwidth,(unsigned short)300);
+  Cnfvsli_SkipArt->setPropertyV(WSNanchorTop,(unsigned short)180);
+  Cnfvsli_SkipArt->setPropertyV(WSNanchorRight,(unsigned short)20);
+  Cnfvsli_SkipArt->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvsli_SkipArt->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
+    WSCprocedure* op_Cnfvsli_SkipArt_5 = new WSCprocedure("CnfSkipArtSliChg",3);
+    extern void CnfSkipArtSliChg(WSCbase*);
+    op_Cnfvsli_SkipArt_5->setFunction(CnfSkipArtSliChg,"CnfSkipArtSliChg");
+    Cnfvsli_SkipArt->addProcedure(op_Cnfvsli_SkipArt_5);
+
+  Cnfvifi_SkipArt = new  WSCvifield(Cnfdial_ConfigUrl,"Cnfvifi_SkipArt");
+      Cnfvifi_SkipArt->initialize();
+  Cnfvifi_SkipArt->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Cnfvifi_SkipArt->setPropertyV(WSNname,"Cnfvifi_SkipArt");
+  Cnfvifi_SkipArt->setPropertyV(WSNvis,(WSCbool)1);
+  Cnfvifi_SkipArt->setPropertyV(WSNx,(short)220);
+  Cnfvifi_SkipArt->setPropertyV(WSNy,(short)180);
+  Cnfvifi_SkipArt->setPropertyV(WSNanchorTop,(unsigned short)180);
+  Cnfvifi_SkipArt->setPropertyV(WSNanchorLeft,(unsigned short)220);
+  Cnfvifi_SkipArt->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Cnfvifi_SkipArt->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Cnfvifi_SkipArt_5 = new WSCprocedure("CnfSkipArtIfiChg",3);
+    extern void CnfSkipArtIfiChg(WSCbase*);
+    op_Cnfvifi_SkipArt_5->setFunction(CnfSkipArtIfiChg,"CnfSkipArtIfiChg");
+    Cnfvifi_SkipArt->addProcedure(op_Cnfvifi_SkipArt_5);
+
+  Maivtim_ReloadTimer = new  WSCvtimer(MainWin,"Maivtim_ReloadTimer");
+      Maivtim_ReloadTimer->initialize();
+  Maivtim_ReloadTimer->setPropertyV(WSNinterval,(unsigned long)3600000);
+  Maivtim_ReloadTimer->setPropertyV(WSNrunning,(WSCbool)1);
+  Maivtim_ReloadTimer->setPropertyV(WSNname,"Maivtim_ReloadTimer");
+  Maivtim_ReloadTimer->setPropertyV(WSNvis,(WSCbool)1);
+  Maivtim_ReloadTimer->setPropertyV(WSNx,(short)80);
+  Maivtim_ReloadTimer->setPropertyV(WSNy,(short)180);
+  Maivtim_ReloadTimer->setPropertyV(WSNwidth,(unsigned short)60);
+    WSCprocedure* op_Maivtim_ReloadTimer_5 = new WSCprocedure("ReloadTimerUpdate",2);
+    extern void ReloadTimerUpdate(WSCbase*);
+    op_Maivtim_ReloadTimer_5->setFunction(ReloadTimerUpdate,"ReloadTimerUpdate");
+    Maivtim_ReloadTimer->addProcedure(op_Maivtim_ReloadTimer_5);
+
    MainWin->setVisible(True);
    return MainWin;
 }
