@@ -11,17 +11,19 @@ private:
 	WSClistData mStrUrl;
 	WSClistData mFlagDownload;
 	WSClistData mEncoding;
+	WSClistData mSkipArt;
 public:
 	void CUrl::Init( void );
 	void CUrl::Reset( void );
 
 	bool CUrl::Add(
 		WSCstring name,
-		WSCstring url, bool flagDown, long encoding );
+		WSCstring url, bool flagDown, long encoding, long skipArt );
 	bool CUrl::Update(
 		WSCstring oldName, WSCstring name,
-		WSCstring url, bool flagDown, long encoding );
+		WSCstring url, bool flagDown, long encoding, long skipArt );
 	bool CUrl::Delete( WSCstring name );
+	bool CUrl::Swap( long n1, long n2 );
 
 	long CUrl::GetN( WSCstring name );
 	long CUrl::GetMaxN( void ){
@@ -46,6 +48,11 @@ public:
 	long CUrl::GetEncoding( long n );
 	long CUrl::SetEncoding( WSCstring name, long en );
 	long CUrl::SetEncoding( long n, long en );
+
+	long CUrl::GetSkipArt( WSCstring name );
+	long CUrl::GetSkipArt( long n );
+	long CUrl::SetSkipArt( WSCstring name, long artN );
+	long CUrl::SetSkipArt( long n, long artN );
 };
 
 extern CUrl gUrl;
